@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-journal
 version: 0.7.1
-id: monad-journal-0.7.1-821bbaf50681c3e04fb012872c12c421
-key: monad_89BhujpEoBaIpkm2XOmxHQ
+id: monad-journal-0.7.1-739d84421c9ca464fb6d425a63272956
+key: monad_9EdQ4ZNoZOeARe9k8puCng
 license: BSD3
 maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
 homepage: http://github.com/phaazon/monad-journal
@@ -25,10 +25,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.1
-hs-libraries: HSmonad-journal-0.7.1-89BhujpEoBaIpkm2XOmxHQ
+hs-libraries: HSmonad-journal-0.7.1-9EdQ4ZNoZOeARe9k8puCng
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-0ad66f7e12d699216df063a503e72063
+    either-4.4.1-6e9670c0aa10adc0c05cea76c41fcbb1
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
